Package: gdtools
Title: Font Metrics and Font Management Utilities for R Graphics
Version: 0.5.1
Authors@R: c(
    person("David", "Gohel", , "david.gohel@ardata.fr", role = c("aut", "cre")),
    person("Hadley", "Wickham", , "hadley@rstudio.com", role = "aut"),
    person("Lionel", "Henry", , "lionel@rstudio.com", role = "aut"),
    person("Jeroen", "Ooms", , "jeroen@berkeley.edu", role = "aut",
           comment = c(ORCID = "0000-0002-4035-0289")),
    person("Yixuan", "Qiu", role = "ctb"),
    person("R Core Team", role = "cph",
           comment = "Cairo code from X11 device"),
    person("ArData", role = "cph"),
    person("RStudio", role = "cph")
  )
Description: Compute text metrics (width, ascent, descent) using 'Cairo'
    and 'FreeType', independently of the active graphic device. Font
    lookup is delegated to 'systemfonts'. Additional utilities let users
    register 'Google Fonts' or bundled 'Liberation' fonts, check font
    availability, and assemble 'htmlDependency' objects so that fonts are
    correctly embedded in 'Shiny' applications, 'R Markdown' documents,
    and 'htmlwidgets' outputs such as 'ggiraph'.
License: GPL-3 | file LICENSE
URL: https://davidgohel.github.io/gdtools/
BugReports: https://github.com/davidgohel/gdtools/issues
Depends: R (>= 4.0.0)
Imports: fontquiver (>= 0.2.0), htmltools, Rcpp (>= 0.12.12),
        systemfonts (>= 1.3.1), tools
Suggests: curl, gfonts, methods, testthat
LinkingTo: Rcpp
Encoding: UTF-8
SystemRequirements: cairo, freetype2, fontconfig
Config/roxygen2/version: 8.0.0
NeedsCompilation: yes
Packaged: 2026-05-25 16:16:18 UTC; davidgohel
Author: David Gohel [aut, cre],
  Hadley Wickham [aut],
  Lionel Henry [aut],
  Jeroen Ooms [aut] (ORCID: <https://orcid.org/0000-0002-4035-0289>),
  Yixuan Qiu [ctb],
  R Core Team [cph] (Cairo code from X11 device),
  ArData [cph],
  RStudio [cph]
Maintainer: David Gohel <david.gohel@ardata.fr>
Repository: CRAN
Date/Publication: 2026-05-25 17:10:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-05-25 17:44:01 UTC; unix
Archs: gdtools.so.dSYM
