# Generated by roxygen2: do not edit by hand

S3method(print,font_set)
export(addGFontHtmlDependency)
export(check_gfonts)
export(dummy_setup)
export(font_family_exists)
export(font_google)
export(font_liberation)
export(font_set)
export(font_set_auto)
export(font_set_liberation)
export(fonts_cache_dir)
export(gfontHtmlDependency)
export(init_fonts_cache)
export(install_gfont_script)
export(installed_gfonts)
export(liberationmonoHtmlDependency)
export(liberationsansHtmlDependency)
export(liberationserifHtmlDependency)
export(m_str_extents)
export(match_family)
export(register_gfont)
export(register_liberationmono)
export(register_liberationsans)
export(register_liberationserif)
export(rm_fonts_cache)
export(set_dummy_conf)
export(str_metrics)
export(strings_sizes)
export(sys_fonts)
export(version_cairo)
export(version_freetype)
importFrom(Rcpp,sourceCpp)
importFrom(fontquiver,font_faces)
importFrom(grDevices,is.raster)
importFrom(htmltools,attachDependencies)
importFrom(htmltools,htmlDependency)
importFrom(htmltools,tags)
importFrom(systemfonts,match_fonts)
importFrom(systemfonts,register_font)
importFrom(systemfonts,registry_fonts)
importFrom(systemfonts,system_fonts)
importFrom(tools,R_user_dir)
importFrom(utils,packageVersion)
useDynLib(gdtools)
