# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

str_metrics_ <- function(x, fontname = "sans", fontsize = 12, bold = FALSE, italic = FALSE, fontfile = "") {
    .Call('_gdtools_str_metrics_', PACKAGE = 'gdtools', x, fontname, fontsize, bold, italic, fontfile)
}

m_str_extents_ <- function(x, fontname, fontsize, bold, italic, fontfile) {
    .Call('_gdtools_m_str_extents_', PACKAGE = 'gdtools', x, fontname, fontsize, bold, italic, fontfile)
}

m_str_metrics_ <- function(x, fontname, fontsize, bold, italic, fontfile) {
    .Call('_gdtools_m_str_metrics_', PACKAGE = 'gdtools', x, fontname, fontsize, bold, italic, fontfile)
}

#' @rdname version_cairo
#' @export
version_freetype <- function() {
    .Call('_gdtools_version_freetype', PACKAGE = 'gdtools')
}

version_cairo_ <- function() {
    .Call('_gdtools_version_cairo_', PACKAGE = 'gdtools')
}

